@@ -28,9 +28,13 @@ OC.L10N.register(
     "Download" : "הורדה",
     "Delete" : "מחיקה",
     "Unshare" : "ביטול שיתוף",
+    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "פעולה זו תמחק את לוח השנה „{calendar}” ואת כל האירועים והמשימות הקשורים אליו.",
+    "This will unshare the calendar \"{calendar}\"." : "פעולה זו תבטל את שיתוף לוח השנה „{calendar}”.",
     "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
     "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["לוח השנה יימחק בעוד שנייה","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["שיתוף לוח השנה יפסק בעוד שנייה","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["משותף עם ישות אחת","משותף עם {num} ישויות","משותף עם {num} ישויות","משותף עם {num} ישויות"],
     "Default list" : "רשימת בררת מחדל",
     "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
@@ -86,9 +90,15 @@ OC.L10N.register(
     "[Completed today at] LT" : "[הושלמה היום בשעה] LT",
     "[Completed tomorrow at] LT" : "[תושלם מחר בשעה] LT",
     "[Completed] L [at] LT" : "[הושלמה] L [בשעה] LT",
+    "Add a subtask to \"{task}\"…" : "הוספת תת־משימה אל „{task}”",
     "An error occurred, unable to delete the task." : "אירעה שגיאה, אין אפשרות למחוק את המשימה.",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["המשימה תימחק בעוד שנייה","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות"],
+    "Add a task to \"{task}\"…" : "הוספת משימה אל „{task}”",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
+    "Add an important task to \"{calendar}\"…" : "הוספת משימה חשובה אל „{calendar}”",
+    "Add a task due today to \"{calendar}\"…" : "הוספה משימה שמועד תפוגתה הוא היום אל „{calendar}”",
+    "Add a current task to \"{calendar}\"…" : "הוספת משימה נוכחית אל „{calendar}”",
+    "Add a task to \"{calendar}\"…" : "הוספת משימה אל „{calendar}”",
     "Tomorrow" : "מחר",
     "Set start date" : "קביעת תאריך התחלה",
     "Set start time" : "הגדרת זמן התחלה",
