@@ -9,16 +9,18 @@ OC.L10N.register(
     "Completed" : "Befejezve",
     "Tasks" : "Feladatok",
     "The Tasks app for Nextcloud" : "Feladatok alkalmazás Nextcloud-hoz",
+    "Add List…" : "Lista hozzáadása...",
+    "New List" : "Új lista",
+    "Cancel" : "Mégsem",
+    "Save" : "Mentés",
+    "The name \"{calendar}\" is already used." : "Ez a név \"[calendar]\" már foglalt.",
+    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
     "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
     "No users or groups" : "Nincsenek felhasználók vagy csoportok.",
     "can edit" : "módosíthat ",
     "Unshare with {displayName}" : "Megosztás {displayName}-vel törölve",
     "Unable to delete the share." : "Nem lehet törölni a megosztást.",
     "Unable to change permissions." : "Nem lehet változtatni az engedélyeket.",
-    "New List" : "Új lista",
-    "Cancel" : "Mégsem",
-    "Save" : "Mentés",
-    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
     "Edit" : "Szerkesztés",
     "Copy private link" : "Személyes hivatkozás másolása",
     "Copied" : "Másolva",
@@ -26,6 +28,7 @@ OC.L10N.register(
     "Download" : "Letöltés",
     "Delete" : "Törlés",
     "Unshare" : "Megosztás visszavonása",
+    "This will unshare the calendar \"{calendar}\"." : "Ez visszavonja a megosztást erről a naptárról \"[calendar]\".",
     "Calendar link copied to clipboard." : "Naptár hivatkozás a vágólapra másolva.",
     "Calendar link could not be copied to clipboard." : "Naptári hivatkozást nem lehet vágólapra másolni.",
     "An error occurred, unable to delete the calendar." : "Hiba lépett fel, a naptárat nem lehet törölni.",
