@@ -9,15 +9,18 @@ OC.L10N.register(
     "Completed" : "Ferdig",
     "Tasks" : "Oppgaver",
     "The Tasks app for Nextcloud" : "Oppgave-appen for Nextcloud",
+    "Add List…" : "Legg til liste...",
     "New List" : "Ny liste",
     "Cancel" : "Avbryt",
     "Save" : "Lagre",
+    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
     "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan redigere",
     "Unshare with {displayName}" : "Fjern deling med {displayName}",
     "Unable to delete the share." : "Kan ikke slette delingen.",
+    "Unable to change permissions." : "Kunne ikke endre rettigheter.",
     "Edit" : "Rediger",
     "Copy private link" : "Kopier privat lenke",
     "Copied" : "Kopiert",
@@ -27,20 +30,33 @@ OC.L10N.register(
     "Unshare" : "Opphev deling",
     "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
     "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
+    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
+    "Default list" : "Standardliste",
     "Visibility of Smart Collections" : "Synlighet for smarte samlinger",
     "Hidden" : "Skjult",
     "Visible" : "Synlig",
     "Automatic" : "Automatisk",
+    "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
+    "Delete completed tasks." : "Slett fullførte oppgaver.",
+    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
     "No errors" : "Ingen feil",
     "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
     "Change sort order" : "Endre sorteringsrekkefølge",
+    "Relevance" : "Relevans",
     "Start date" : "Startdato",
     "Due date" : "Forfallsdato",
+    "Created date" : "Opprettelsesdato",
     "Last modified" : "Sist redigert",
     "Priority" : "Prioritet",
     "Alphabetically" : "Alfabetisk",
     "Manually" : "Manuelt",
     "Task is completed" : "Oppgaven er fullført",
+    "Add subtask" : "Legg til underoppgave",
+    "Show subtasks" : "Vis underoppgaver",
+    "Hide subtasks" : "Skjul underoppgaver",
+    "Hide completed subtasks" : "Skjul fullførte underoppgaver",
+    "Delete task" : "Slett oppgave",
+    "An error occurred, unable to delete the task." : "Det oppstod en feil, kunne ikke slette oppgaven.",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n utført oppgave","%n avsluttede oppgaver"],
     "Tomorrow" : "I morgen",
     "Set start date" : "Sett startdato",
@@ -51,6 +67,9 @@ OC.L10N.register(
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
     "When shared hide this event" : "Skjul denne hendelsen når delt",
+    "Needs action" : "Krever handling",
+    "Canceled" : "Avbrutt",
+    "Could not delete the task." : "Kunne ikke slette oppgaven.",
     "An error occurred" : "En feil oppstod"
 },
 "nplurals=2; plural=(n != 1);");
