@@ -9,22 +9,23 @@ OC.L10N.register(
     "Completed" : "Завершені",
     "Tasks" : "Завдання",
     "The Tasks app for Nextcloud" : "Застосунок Завдання (Tasks) для Nextcloud",
-    "Share with users or groups" : "Поділитися з користувачем або групою",
-    "No users or groups" : "Жодного користувача або групм",
-    "can edit" : "може редагувати",
-    "Unshare with {displayName}" : "Припинити поширення з {displayName}",
-    "Unable to delete the share." : "Неможливо вилучити спільний елемент.",
     "Add List…" : "Додати список",
     "New List" : "Новий список",
     "Cancel" : "Скасувати",
     "Save" : "Зберегти",
     "An empty name is not allowed." : "Порожнє поле не допускається.",
+    "Share with users or groups" : "Поділитися з користувачем або групою",
+    "No users or groups" : "Жодного користувача або групм",
+    "can edit" : "може редагувати",
+    "Unshare with {displayName}" : "Припинити поширення з {displayName}",
+    "Unable to delete the share." : "Неможливо вилучити спільний елемент.",
+    "Unable to change permissions." : "Неможливо змінити права доступу.",
     "Edit" : "Редагувати",
     "Copy private link" : "Копіювати приватне посилання",
     "Copied" : "Скопійовано",
     "Can not copy" : "Неможливо скопіювати",
     "Download" : "Завантажити",
-    "Delete" : "Видалити",
+    "Delete" : "Вилучити",
     "Unshare" : "Закрити доступ",
     "Calendar link copied to clipboard." : "Посилання на календар зкопійовано до буфера обміну",
     "Calendar link could not be copied to clipboard." : "Посилання на календар не може бути зкопійоване до буфера обміну",
@@ -35,6 +36,7 @@ OC.L10N.register(
     "Visible" : "Видимий",
     "Automatic" : "Автоматично",
     "No errors" : "Без помилок",
+    "Open your browser console for more details" : "Відкрийте консоль браузера для докладної інформації",
     "Change sort order" : "Зміна порядку сортування",
     "Relevance" : "Відповідність",
     "Start date" : "Дата початку",
@@ -45,16 +47,22 @@ OC.L10N.register(
     "Alphabetically" : "За алфавітом",
     "Manually" : "Вручну",
     "Task is completed" : "Завдання виконано",
+    "Add subtask" : "Додати підзавдання",
+    "Delete task" : "Вилучити завдання",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань","%n завершених завдань"],
     "Tomorrow" : "Завтра",
     "Set start date" : "Встановити дату початку",
+    "Set start time" : "Встановити початок",
     "Set due date" : "Встановіть термін",
+    "Set due time" : "Встановити час завершення",
     "All day" : "Всі дні",
+    "Select a calendar" : "Вибрати календар",
     "Add this as a new category" : "Додати це як нову категорію",
     "Task not found!" : "Завдання не знайдене!",
     "When shared show full event" : "При поширенні показувати подію повністю",
     "When shared show only busy" : "При поширенні показувати тільки зайнятий час",
     "When shared hide this event" : "При поширенні приховати цю подію",
+    "Canceled" : "Скасовано",
     "An error occurred" : "Виникла помилка"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
